﻿// (C) Copyright 2010 by Autodesk, Inc. 
//
// Permission to use, copy, modify, and distribute this software
// in object code form for any purpose and without fee is hereby
// granted, provided that the above copyright notice appears in
// all copies and that both that copyright notice and the limited
// warranty and restricted rights notice below appear in all
// supporting documentation.
//
// AUTODESK PROVIDES THIS PROGRAM "AS IS" AND WITH ALL FAULTS. 
// AUTODESK SPECIFICALLY DISCLAIMS ANY IMPLIED WARRANTY OF
// MERCHANTABILITY OR FITNESS FOR A PARTICULAR USE.  AUTODESK,
// INC. DOES NOT WARRANT THAT THE OPERATION OF THE PROGRAM WILL
// BE UNINTERRUPTED OR ERROR FREE.
//
// Use, duplication, or disclosure by the U.S. Government is
// subject to restrictions set forth in FAR 52.227-19 (Commercial
// Computer Software - Restricted Rights) and DFAR 252.227-7013(c)
// (1)(ii)(Rights in Technical Data and Computer Software), as
// applicable.
//

using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using Autodesk.Navisworks.Api;

namespace Colouriser
{
    [Serializable]
    abstract class Assignment
    {
        private System.Drawing.Color m_colour;
        private double m_transparency = 0.5;

        public Assignment(System.Drawing.Color colour)//, int transparency)
        {
            m_colour = colour;
            //m_transparency = (double)transparency / 100.0;
        }

        public void Apply()
        {
            //
            // Get items and override colour.
            //
            IEnumerable<ModelItem> items = GetSelection();
            Application.ActiveDocument.Models.OverridePermanentColor(items, NavisworksColour);
            Application.ActiveDocument.Models.OverridePermanentTransparency(items, m_transparency);
        }

        public void Select()
        {
            //
            // Get items and update current selection.
            //
            IEnumerable<ModelItem> items = GetSelection();
            Application.ActiveDocument.CurrentSelection.CopyFrom(items);
        }

        public Autodesk.Navisworks.Api.Color NavisworksColour
        {
            get
            {
                //
                // Use helper method to convert from Windows colour to Navisworks colour.
                //
                return Autodesk.Navisworks.Api.Color.FromByteRGB(m_colour.R, m_colour.G, m_colour.B);
            }
        }

        abstract public IEnumerable<ModelItem> GetSelection();
    }
}
