﻿// (C) Copyright 2010 by Autodesk, Inc. 
//
// Permission to use, copy, modify, and distribute this software
// in object code form for any purpose and without fee is hereby
// granted, provided that the above copyright notice appears in
// all copies and that both that copyright notice and the limited
// warranty and restricted rights notice below appear in all
// supporting documentation.
//
// AUTODESK PROVIDES THIS PROGRAM "AS IS" AND WITH ALL FAULTS. 
// AUTODESK SPECIFICALLY DISCLAIMS ANY IMPLIED WARRANTY OF
// MERCHANTABILITY OR FITNESS FOR A PARTICULAR USE.  AUTODESK,
// INC. DOES NOT WARRANT THAT THE OPERATION OF THE PROGRAM WILL
// BE UNINTERRUPTED OR ERROR FREE.
//
// Use, duplication, or disclosure by the U.S. Government is
// subject to restrictions set forth in FAR 52.227-19 (Commercial
// Computer Software - Restricted Rights) and DFAR 252.227-7013(c)
// (1)(ii)(Rights in Technical Data and Computer Software), as
// applicable.
//

using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using System.IO;
using System.Runtime.Serialization.Formatters.Binary;
using System.Runtime.Serialization;

using Nw = Autodesk.Navisworks.Api;

using Autodesk.Navisworks.Api.ComApi;
using Autodesk.Navisworks.Api.Interop.ComApi;

namespace Colouriser
{
    public partial class MainForm : Form
    {
        public MainForm()
        {
            InitializeComponent();
        }

        private void buttonClose_Click(object sender, EventArgs e)
        {
            this.Visible = false;
        }

        private void buttonColour_Click(object sender, EventArgs e)
        {
            colorDialog.Color = buttonColour.BackColor;
            if (colorDialog.ShowDialog() == DialogResult.OK)
            {
                buttonColour.BackColor = colorDialog.Color;
            }
        }

        private void buttonAdd_Click(object sender, EventArgs e)
        {
            Assignment ass = null;
            switch (tabControl1.SelectedIndex)
            {
                case 0:
                    {
                        if (!String.IsNullOrEmpty(textPropCat.Text) && !String.IsNullOrEmpty(textProp.Text))
                        {
                            ass = new PropertyAssignment(textPropCat.Text, textProp.Text, textValue.Text, buttonColour.BackColor);
                        }
                    }
                    break;
                case 1:
                    {
                        if (listSelectionSets.SelectedItem != null)
                        {
                            ass = new SelectionSetAssignment(listSelectionSets.SelectedItem.ToString(), buttonColour.BackColor);
                        }
                    }
                    break;
            }
            if (ass != null)
            {
                listAssignments.Items.Add(ass);
            }
        }

        private void buttonRemove_Click(object sender, EventArgs e)
        {
            if (listAssignments.SelectedItem != null)
            {
                listAssignments.Items.Remove(listAssignments.SelectedItem);
            }
        }

        private void buttonTestProp_Click(object sender, EventArgs e)
        {
            if (listAssignments.SelectedItem != null)
            {
                Assignment ass = listAssignments.SelectedItem as Assignment;
                ass.Select();
            }
        }

        private void buttonRun_Click(object sender, EventArgs e)
        {
            foreach (Assignment ass in listAssignments.Items)
            {
                ass.Apply();
            }
        }

        private void buttonReset_Click(object sender, EventArgs e)
        {
            //
            // Reset all overridden colours.
            //
            Nw.Application.ActiveDocument.Models.ResetAllPermanentMaterials();
        }

        #region Serialisation
        private void buttonLoad_Click(object sender, EventArgs e)
        {
            IEnumerable<Assignment> assignments = LoadRules();
            if (assignments != null)
            {
                listAssignments.Items.Clear();
                foreach (Assignment ass in assignments)
                {
                    listAssignments.Items.Add(ass);
                }
            }
        }

        private void buttonSave_Click(object sender, EventArgs e)
        {
            FileStream fs = new FileStream(@"C:\Users\priestm\rules.dat", FileMode.Create);
            try
            {
                BinaryFormatter formatter = new BinaryFormatter();
                List<Assignment> assignments = new List<Assignment>();
                foreach (Assignment ass in listAssignments.Items)
                {
                    assignments.Add(ass);
                }
                formatter.Serialize(fs, assignments);
            }
            catch (SerializationException exception)
            {
                Console.WriteLine("Failed to serialize. Reason: " + exception.Message);
                throw;
            }
            finally
            {
                fs.Close();
            }
        }

        private IEnumerable<Assignment> LoadRules()
        {
            List<Assignment> assignments = null;
            FileStream fs = new FileStream(@"C:\Users\priestm\rules.dat", FileMode.OpenOrCreate);
            try
            {
                BinaryFormatter formatter = new BinaryFormatter();
                assignments = (List<Assignment>)formatter.Deserialize(fs);
            }
            catch (SerializationException exception)
            {
                Console.WriteLine("Failed to serialize. Reason: " + exception.Message);
                throw;
            }
            finally
            {
                fs.Close();
            }
            return assignments;
        }

        public int BatchApplyRules()
        {
            IEnumerable<Assignment> assignments = LoadRules();
            if (assignments != null)
            {
                foreach (Assignment ass in assignments)
                {
                    ass.Apply();
                }
            }
            return 0;
        }
        #endregion

        private void MainForm_Load(object sender, EventArgs e)
        {
            Nw.Application.ActiveDocument.Models.CollectionChanged += new EventHandler<EventArgs>(Models_CollectionChanged);
            RefreshSelectionSetList();
        }

        void Models_CollectionChanged(object sender, EventArgs e)
        {
            RefreshSelectionSetList();
        }

        private void RefreshSelectionSetList()
        {
            //
            // Access selection sets using COM Interop.
            //
            listSelectionSets.Items.Clear();
            InwOpState10 state = ComApiBridge.State;
            if (state != null)
            {
                InwSelectionSetColl sets = state.SelectionSets();
                if (sets != null)
                {
                    foreach (InwOpSelectionSet set in sets)
                    {
                        listSelectionSets.Items.Add(set.name);
                    }
                }
            }
        }

        private void buttonHideRest_Click(object sender, EventArgs e)
        {
            Nw.ModelItemCollection all_items = new Nw.ModelItemCollection();

            foreach (Assignment ass in listAssignments.Items)
            {
                IEnumerable<Nw.ModelItem> items = ass.GetSelection();
                all_items.AddRange(items);
            }

            Nw.Application.ActiveDocument.CurrentSelection.CopyFrom(all_items);
        }
    }
}
