﻿// (C) Copyright 2010 by Autodesk, Inc. 
//
// Permission to use, copy, modify, and distribute this software
// in object code form for any purpose and without fee is hereby
// granted, provided that the above copyright notice appears in
// all copies and that both that copyright notice and the limited
// warranty and restricted rights notice below appear in all
// supporting documentation.
//
// AUTODESK PROVIDES THIS PROGRAM "AS IS" AND WITH ALL FAULTS. 
// AUTODESK SPECIFICALLY DISCLAIMS ANY IMPLIED WARRANTY OF
// MERCHANTABILITY OR FITNESS FOR A PARTICULAR USE.  AUTODESK,
// INC. DOES NOT WARRANT THAT THE OPERATION OF THE PROGRAM WILL
// BE UNINTERRUPTED OR ERROR FREE.
//
// Use, duplication, or disclosure by the U.S. Government is
// subject to restrictions set forth in FAR 52.227-19 (Commercial
// Computer Software - Restricted Rights) and DFAR 252.227-7013(c)
// (1)(ii)(Rights in Technical Data and Computer Software), as
// applicable.
//

using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using Autodesk.Navisworks.Api;

namespace Colouriser
{
    [Serializable]
    class PropertyAssignment : Assignment
    {
        private string m_category;
        private string m_property;
        private string m_value;

        public PropertyAssignment(string category, string property, string value, System.Drawing.Color colour) :
            base(colour)
        {
            m_category = category;
            m_property = property;
            if (!String.IsNullOrEmpty(value))
            {
                m_value = value;
            }
        }

        public override IEnumerable<Autodesk.Navisworks.Api.ModelItem> GetSelection()
        {
            //
            // Use a Search to find the required items.
            //
            Search s = new Search();
            s.Selection.SelectAll();

            SearchCondition condition = SearchCondition.HasPropertyByDisplayName(m_category, m_property);
            if(m_value != null)
            {
                condition = condition.EqualValue(VariantData.FromDisplayString(m_value));
            }
            s.SearchConditions.Add(condition);

            return s.FindAll(Application.ActiveDocument, false);
        }

        public override string ToString()
        {
            string name = m_category + " - " + m_property;
            if (m_value != null)
            {
                name += " = '" + m_value + "'";
            }
            return name;
        }
    }
}
