﻿// (C) Copyright 2010 by Autodesk, Inc. 
//
// Permission to use, copy, modify, and distribute this software
// in object code form for any purpose and without fee is hereby
// granted, provided that the above copyright notice appears in
// all copies and that both that copyright notice and the limited
// warranty and restricted rights notice below appear in all
// supporting documentation.
//
// AUTODESK PROVIDES THIS PROGRAM "AS IS" AND WITH ALL FAULTS. 
// AUTODESK SPECIFICALLY DISCLAIMS ANY IMPLIED WARRANTY OF
// MERCHANTABILITY OR FITNESS FOR A PARTICULAR USE.  AUTODESK,
// INC. DOES NOT WARRANT THAT THE OPERATION OF THE PROGRAM WILL
// BE UNINTERRUPTED OR ERROR FREE.
//
// Use, duplication, or disclosure by the U.S. Government is
// subject to restrictions set forth in FAR 52.227-19 (Commercial
// Computer Software - Restricted Rights) and DFAR 252.227-7013(c)
// (1)(ii)(Rights in Technical Data and Computer Software), as
// applicable.
//

using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;

using Autodesk.Navisworks.Api.ComApi;
using Autodesk.Navisworks.Api.Interop.ComApi;

namespace Colouriser
{
    [Serializable]
    class SelectionSetAssignment : Assignment
    {
        string m_selection_set;

        public SelectionSetAssignment(string selection_set, System.Drawing.Color colour) :
            base(colour)
        {
            m_selection_set = selection_set;
        }

        public string SelectionSet
        {
            get { return m_selection_set; }
        }

        public override IEnumerable<Autodesk.Navisworks.Api.ModelItem> GetSelection()
        {
            //
            // Use the COM Interop to access selection sets.
            //
            InwOpState10 state = ComApiBridge.State;
            InwSelectionSetColl sets = state.SelectionSets();
            foreach (InwOpSelectionSet set in sets)
            {
                if (set.name == m_selection_set)
                {
                    //
                    // Use ComApiBridge to do type conversion.
                    //
                    InwOpSelection selection = set.selection;
                    return ComApiBridge.ToModelItemCollection(selection);
                }
            }
            return null;
        }

        public override string ToString()
        {
            return m_selection_set;
        }
    }
}
