﻿// (C) Copyright 2010 by Autodesk, Inc. 
//
// Permission to use, copy, modify, and distribute this software
// in object code form for any purpose and without fee is hereby
// granted, provided that the above copyright notice appears in
// all copies and that both that copyright notice and the limited
// warranty and restricted rights notice below appear in all
// supporting documentation.
//
// AUTODESK PROVIDES THIS PROGRAM "AS IS" AND WITH ALL FAULTS. 
// AUTODESK SPECIFICALLY DISCLAIMS ANY IMPLIED WARRANTY OF
// MERCHANTABILITY OR FITNESS FOR A PARTICULAR USE.  AUTODESK,
// INC. DOES NOT WARRANT THAT THE OPERATION OF THE PROGRAM WILL
// BE UNINTERRUPTED OR ERROR FREE.
//
// Use, duplication, or disclosure by the U.S. Government is
// subject to restrictions set forth in FAR 52.227-19 (Commercial
// Computer Software - Restricted Rights) and DFAR 252.227-7013(c)
// (1)(ii)(Rights in Technical Data and Computer Software), as
// applicable.
//

using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using Nw = Autodesk.Navisworks.Api;
using Autodesk.Navisworks.Api.Controls;

using Autodesk.Navisworks.Api.ComApi;
using Autodesk.Navisworks.Api.Interop.ComApi;

namespace ComponentViewer
{
    public partial class MainForm : Form
    {
        private string[] m_extensions = {".iam", ".ipt"};

        public MainForm()
        {
            InitializeComponent();

            //
            // Set document as main documnet.
            //
            documentControl1.SetAsMainDocument();

            //
            // Hook up events.
            //
            Nw.Application.ProgressBeginning += new EventHandler<Autodesk.Navisworks.Api.ProgressBeginningEventArgs>(Application_ProgressBeginning);
            Nw.Application.ProgressUpdating += new EventHandler<Autodesk.Navisworks.Api.ProgressUpdatingEventArgs>(Application_ProgressUpdating);
            Nw.Application.ActiveDocument.CurrentSelection.Changed += new EventHandler<EventArgs>(CurrentSelection_Changed);
        }

        void CurrentSelection_Changed(object sender, EventArgs e)
        {
            //
            // Update item name display.
            //
            if (Nw.Application.ActiveDocument.CurrentSelection.SelectedItems.Count == 1)
            {
                Nw.ModelItem item = Nw.Application.ActiveDocument.CurrentSelection.SelectedItems[0];
                Nw.DataProperty prop = item.PropertyCategories.FindPropertyByName(Nw.PropertyCategoryNames.Item, Nw.DataPropertyNames.ItemName);
                if (prop != null)
                {
                    textName.Text = prop.Value.ToDisplayString();
                }
            }
            else
            {
                textName.Text = "";
            }
        }

        void Application_ProgressUpdating(object sender, Autodesk.Navisworks.Api.ProgressUpdatingEventArgs e)
        {
            progressBar1.Value = (int)(e.OverallFractionDone * 100.0);
        }

        void Application_ProgressBeginning(object sender, Autodesk.Navisworks.Api.ProgressBeginningEventArgs e)
        {
            progressBar1.Value = 0;
        }

       private void buttonBrowse_Click(object sender, EventArgs e)
        {
            if (this.folderBrowserDialog1.ShowDialog() == DialogResult.OK)
            {
                listComponents.Items.Clear();
                foreach (string filename in System.IO.Directory.GetFiles(folderBrowserDialog1.SelectedPath))
                {
                    if(m_extensions.Contains(System.IO.Path.GetExtension(filename)))
                    {
                        listComponents.Items.Add(new PartInfo(filename));
                    }
                }
            }
        }

        private void buttonRotate_Click(object sender, EventArgs e)
        {
            //
            // Change current tool here.
            //
            documentControl1.Document.Tool.Value = Nw.Tool.NavigateFreeOrbit;
        }

        private void buttonSelect_Click(object sender, EventArgs e)
        {
            documentControl1.Document.Tool.Value = Nw.Tool.Select;
        }

        private void buttonZoom_Click(object sender, EventArgs e)
        {
            documentControl1.Document.Tool.Value = Nw.Tool.NavigateZoomWindow;
        }

        private void buttonPan_Click(object sender, EventArgs e)
        {
            documentControl1.Document.Tool.Value = Nw.Tool.NavigatePan;
        }

        private void buttonViewAll_Click(object sender, EventArgs e)
        {
            //
            // Need to use some COM Interop functions to perform "View All".
            //
            InwOpState10 state = ComApiBridge.State;
            state.ViewAll();
        }

        private void listComponents_MouseDoubleClick(object sender, MouseEventArgs e)
        {
            //
            // Open a file.
            //
            PartInfo info = listComponents.SelectedItem as PartInfo;
            documentControl1.Document.OpenFile(info.Path);
        }
    }
}
