﻿// (C) Copyright 2010 by Autodesk, Inc. 
//
// Permission to use, copy, modify, and distribute this software
// in object code form for any purpose and without fee is hereby
// granted, provided that the above copyright notice appears in
// all copies and that both that copyright notice and the limited
// warranty and restricted rights notice below appear in all
// supporting documentation.
//
// AUTODESK PROVIDES THIS PROGRAM "AS IS" AND WITH ALL FAULTS. 
// AUTODESK SPECIFICALLY DISCLAIMS ANY IMPLIED WARRANTY OF
// MERCHANTABILITY OR FITNESS FOR A PARTICULAR USE.  AUTODESK,
// INC. DOES NOT WARRANT THAT THE OPERATION OF THE PROGRAM WILL
// BE UNINTERRUPTED OR ERROR FREE.
//
// Use, duplication, or disclosure by the U.S. Government is
// subject to restrictions set forth in FAR 52.227-19 (Commercial
// Computer Software - Restricted Rights) and DFAR 252.227-7013(c)
// (1)(ii)(Rights in Technical Data and Computer Software), as
// applicable.
//

using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using System.Xml.Linq;

// Import namespace
using Nw = Autodesk.Navisworks.Api;

namespace PropView
{
    public partial class PropViewForm : Form
    {
        XElement m_xml_root;

        public PropViewForm()
        {
            InitializeComponent();
            m_xml_root = XElement.Load(@"C:\Users\priestm\ComponentData.xml");

            //
            // Hook up event.
            //
            Nw.Application.ActiveDocument.CurrentSelection.Changed += new EventHandler<EventArgs>(CurrentSelection_Changed);
        }

        void CurrentSelection_Changed(object sender, EventArgs e)
        {
            decimal total = 0;
            listviewParts.Items.Clear();
            //
            // Query for all selected items.
            //
            foreach (Nw.ModelItem item in Nw.Application.ActiveDocument.CurrentSelection.SelectedItems)
            {
                ComponentData data = GetComponentData(item);
                if (data != null)
                {
                    listviewParts.Items.Add(data.GetListViewItem());
                    total += data.Price;
                }
            }
            textTotal.Text = total.ToString();
        }

        private void buttonClose_Click(object sender, EventArgs e)
        {
            this.Visible = false;
        }

        private void buttonSelect_Click(object sender, EventArgs e)
        {
            //
            // Select expensive items using LINQ.
            //
            IEnumerable<Nw.ModelItem> items =
                from item in Nw.Application.ActiveDocument.Models.GetRootItems().DescendantsAndSelf
                where GetPrice(item) > Decimal.Parse(textBox1.Text)
                select item;
            Nw.Application.ActiveDocument.CurrentSelection.CopyFrom(items);
       }

#region ComponentData Handling
        private ComponentData GetComponentData(Nw.ModelItem item)
        {
            //
            // Find propperties by display name.
            // Can use AppInfo to find internal name.
            //
            Nw.DataProperty prop = item.PropertyCategories.FindPropertyByDisplayName("Project", "Part Number");
            if (prop != null)
            {
                //
                // Query external data. Here, we use LINQ to XML.
                //
                IEnumerable<string> data =
                    from el in m_xml_root.Elements("Component")
                    where (string)el.Attribute("name") == prop.Value.ToDisplayString()
                    select el.Element("Price").Value;
                if (data.Count() == 1)
                {
                    return new ComponentData(prop.Value.ToDisplayString(), Decimal.Parse(data.First()));
                }
            }
            return null;
        }

        private decimal GetPrice(Nw.ModelItem item)
        {
            ComponentData data = GetComponentData(item);
            return data != null ? data.Price : 0.0m;
        }
#endregion
    }
}
